@@ -182,7 +182,7 @@ def compute_weights(data, varnames, W_ids, cause_list):
                 denominator = data_beta[
                     (data_beta.min(axis=1) >= 0) & (data_beta.max(axis=1) != np.iinfo(data.dtype).max) & (
                                 data[:, varnames.index(ri)] >= 0)]
-                arities = np.amax(data_beta, axis=0) + 1
+                arities = np.amax(numerator, axis=0) + 1
                 f_w = density_counter(numerator, arities).reshape(arities)
                 f_wr = density_counter(denominator, arities).reshape(arities)
                 weights *= np.array([f_w[tuple(data_delete[i, cause_id])] for i in range(len(data_delete))]) / np.array(
